##
# This file is part of WhatWeb and may be subject to
# redistribution and commercial restrictions. Please see the WhatWeb
# web site for more information on licensing and terms of use.
# http://www.morningstarsecurity.com/research/whatweb
##

# Version 0.2
# removed :certainty=>100
# Version 0.3
# Changed Wallström to Wallstrom

Plugin.define "WordpressSuperCache" do
author "Patrik Wallstrom"
version "0.3"
description "Cache functionality for Wordpress - http://wordpress.org/extend/plugins/wp-super-cache/"


matches [
{:name=>"supercache comment",
:regexp=>/^<!-- Cached page generated by WP-Super-Cache on /}
]

end

